@@ -21,8 +21,8 @@ using namespace Qt::Literals::StringLiterals;
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 
+#include "kldapcore/ldapclientsearchconfig.h"
 #include "kldapcore/ldapserver.h"
-#include "ldapclientsearchconfig.h"
 #include "ldapclientsearchconfigwriteconfigjob.h"
 #include "ldapwidgetitem_p.h"
 #include "ldapwidgetitemreadconfigserverjob.h"
@@ -33,7 +33,7 @@ using namespace KLDAPWidgets;
 
 LdapConfigureWidget::LdapConfigureWidget(QWidget *parent)
     : QWidget(parent)
-    , mClientSearchConfig(new KLDAPWidgets::LdapClientSearchConfig)
+    , mClientSearchConfig(new KLDAPCore::LdapClientSearchConfig)
 {
     initGUI();
 
@@ -191,7 +191,7 @@ void LdapConfigureWidget::slotMoveDown()
 void LdapConfigureWidget::load()
 {
     mHostListView->clear();
-    KConfig *config = KLDAPWidgets::LdapClientSearchConfig::config();
+    KConfig *config = KLDAPCore::LdapClientSearchConfig::config();
     KConfigGroup group(config, QStringLiteral("LDAP"));
 
     int count = group.readEntry("NumSelectedHosts", 0);
@@ -222,8 +222,7 @@ void LdapConfigureWidget::load()
 
 void LdapConfigureWidget::save()
 {
-    // mClientSearchConfig->clearWalletPassword();
-    KConfig *config = KLDAPWidgets::LdapClientSearchConfig::config();
+    KConfig *config = KLDAPCore::LdapClientSearchConfig::config();
     config->deleteGroup(QStringLiteral("LDAP"));
 
     KConfigGroup group(config, QStringLiteral("LDAP"));
@@ -238,7 +237,7 @@ void LdapConfigureWidget::save()
 
         KLDAPCore::LdapServer server = item->server();
         if (item->checkState() == Qt::Checked) {
-            auto job = new LdapClientSearchConfigWriteConfigJob;
+            auto job = new KLDAPCore::LdapClientSearchConfigWriteConfigJob;
             job->setActive(true);
             job->setConfig(group);
             job->setServerIndex(selected);
@@ -246,7 +245,7 @@ void LdapConfigureWidget::save()
             job->start();
             selected++;
         } else {
-            auto job = new LdapClientSearchConfigWriteConfigJob;
+            auto job = new KLDAPCore::LdapClientSearchConfigWriteConfigJob;
             job->setActive(false);
             job->setConfig(group);
             job->setServerIndex(unselected);
@@ -269,7 +268,7 @@ void LdapConfigureWidget::initGUI()
     mainLayout->setObjectName("layout"_L1);
 
     // Contents of the QVGroupBox: label and hbox
-    auto label = new QLabel(i18n("Check all servers that should be used:"), this);
+    auto label = new QLabel(i18nc("@label:textbox", "Check all servers that should be used:"), this);
     mainLayout->addWidget(label);
 
     auto hBox = new QWidget(this);
@@ -303,12 +302,12 @@ void LdapConfigureWidget::initGUI()
     upDownBoxVBoxLayout->setStretchFactor(spacer, 100);
 
     auto buttons = new QDialogButtonBox(this);
-    QPushButton *add = buttons->addButton(i18n("&Add Host..."), QDialogButtonBox::ActionRole);
+    QPushButton *add = buttons->addButton(i18nc("@action:button", "&Add Host…"), QDialogButtonBox::ActionRole);
     connect(add, &QPushButton::clicked, this, &LdapConfigureWidget::slotAddHost);
-    mEditButton = buttons->addButton(i18n("&Edit Host..."), QDialogButtonBox::ActionRole);
+    mEditButton = buttons->addButton(i18nc("@action:button", "&Edit Host…"), QDialogButtonBox::ActionRole);
     connect(mEditButton, &QPushButton::clicked, this, &LdapConfigureWidget::slotEditHost);
     mEditButton->setEnabled(false);
-    mRemoveButton = buttons->addButton(i18n("&Remove Host"), QDialogButtonBox::ActionRole);
+    mRemoveButton = buttons->addButton(i18nc("@action:button", "&Remove Host"), QDialogButtonBox::ActionRole);
     connect(mRemoveButton, &QPushButton::clicked, this, &LdapConfigureWidget::slotRemoveHost);
     mRemoveButton->setEnabled(false);
 
