@@ -1,13 +1,13 @@
 /*
- * SPDX-FileCopyrightText: 2020-2023 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #pragma once
 
+#include "kldapcore/ldapserver.h"
 #include <QListWidget>
-#include <kldapcore/ldapserver.h>
 namespace KLDAPWidgets
 {
 class LdapWidgetItem : public QListWidgetItem
